InnerRoute class

Constructors

InnerRoute({required String path, required BuildRoute builder, List<InnerRoute>? innerRoutes})

Properties

builder BuildRoute
final
hashCode int
The hash code for this object.
no setterinherited
innerRoutes List<InnerRoute>?
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited